<?php
if ( ! defined('EXT')) exit('Invalid file request');

/**
 * MonthPicker Class
 * 
 * Based on ycTIN's jQuery monthpicker class: Timmy Tin (ycTIN) http://project.yctin.com/monthpicker
 * 
 * @package   FieldFrame
 * @author    John D Wells
 */
class Monthpicker extends Fieldframe_Fieldtype {
 
	/**
	 * Fieldtype Info
	 * @var array
	 */
    var $info = array(
        'name'             => 'MonthPicker',
        'version'          => '1.1.2',
        'desc'             => 'Creates a month picker fieldtype using ycTIN\'s jQuery monthpicker class.',
        'docs_url'         => 'http://johndwells.com/software',
        'versions_xml_url' => 'http://johndwells.com/software/versions'
    );

    var $requires = array(
    	'ff'		=> '1.0',
        'cp_jquery' => '1.1.0'
    );

	var $default_field_settings = array(
        'copy_to' => 'none',
        'day_and_time' => '-01 12:01 AM'
	);

	var $default_cell_settings = array(
        'copy_to' => 'none',
        'day_and_time' => '-01 12:01 AM'
	);
	
	var $default_tag_params = array(
		'format' => 'M Y'
	);
	
	/**
	 * Display Field Settings
	 * 
	 * @param  array  $field_settings  The field's settings
	 * @return array  Settings HTML (cell1, cell2, rows)
	 */
	function display_field_settings($field_settings)
	{

		global $DSP, $LANG;
		$SD = new Fieldframe_SettingsDisplay();
		
		$options = array(
			'entry' => $LANG->line('entry_date'),
			'expire' => $LANG->line('expiration_date'),
			'both' => $LANG->line('both'),
			'none' => $LANG->line('none')
		);
		
		$r = '';
		$r .= $DSP->div('itemWrapper')
		   .  $DSP->qdiv('defaultBold', $LANG->line('copy_to_label'))
		   .  $DSP->qdiv('', $SD->radio_group('copy_to', $field_settings['copy_to'], $options ))
		   .  $DSP->div_c();

		$r .= $DSP->div('itemWrapper')
		   .  $DSP->qdiv('defaultBold', $LANG->line('day_and_time'))
		   .  $DSP->qdiv('', $SD->text('day_and_time', $field_settings['day_and_time'], array('width' => 100, 'maxlength' => 12) ))
		   .  $DSP->div_c();

		return array('cell2' => $r);
	}
	
	function display_cell_settings($cell_settings)
	{
		global $DSP, $LANG;
		$SD = new Fieldframe_SettingsDisplay();
		
		$r = '';
		$r .= $DSP->div('itemWrapper')
		   .  $DSP->qdiv('defaultBold', $LANG->line('day_and_time'))
		   .  $DSP->qdiv('', $SD->text('day_and_time', $cell_settings['day_and_time'], array('width' => 100, 'maxlength' => 12) ))
		   .  $DSP->div_c();

		return $r;
	}

	/**
	 * Display Field
	 * 
	 * @param  mixed  $field_name
	 * @param  mixed  $field_data
	 * @param  array  $field_settings  The field's settings
	 * @return string  Field HTML
	 */
    function display_field( $field_name, $field_data, $field_settings )
    {
		global $DSP;
		$SD = new Fieldframe_SettingsDisplay();

		$this->include_css('style/css/monthpicker.css');
		$this->include_js('style/scripts/monthpicker.min.js');
		$this->include_js('style/scripts/functions.js');

		// set up the field data (it comes from the DB as a timestamp)
		if($field_data) {
			$month = (int) date('m', $field_data);
			$year = (int) date('Y', $field_data);
		} else {
			$month = (int) date('m');
			$year = (int) date('Y');
		}
		
		$date = $year . '-' . $month . $field_settings['day_and_time'];

		// determine if we need to copy values to other entry dates
		switch($field_settings['copy_to']) {
			case('entry') :
				$copy_to = "monthpicker_copy_to('entry_date', date_and_time);";
				break;

			case('expire') :
				$copy_to = "monthpicker_copy_to('expiration_date', date_and_time);";
				break;

			case('both') :
				$copy_to = "monthpicker_copy_to('entry_date', date_and_time);"
						 . "monthpicker_copy_to('expiration_date', date_and_time);";
				break;

			case('none') :
			default :
				$copy_to = '';
		}

		
		$monthpicker_id = 'monthpicker_' . str_replace(array('[',']'), array('',''), $field_name);

		$r = $DSP->qdiv('hidden', $SD->text($field_name, $date) );
		$r .= <<< EOT
			<div class="MonthPicker" id="{$monthpicker_id}" rel="{$field_name}"></div>
			<script type="text/javascript">

				if(typeof \$monthpickerPrefs == 'undefined')
					var \$monthpickerPrefs = {};

				\$monthpickerPrefs.{$monthpicker_id} = {
					year : "{$year}",
					month : "{$month}",
					copy_to : "{$copy_to}",
					day_and_time : "{$field_settings['day_and_time']}"
				};
				
				jQuery(document).ready(function() {
					
					jQuery('.MonthPicker').siblings('.hidden').css('display', 'none');
				
					jQuery("#{$monthpicker_id}").monthpicker({
						elements: [
							{tpl:"year",opt:{
								type: "button",
								range: "-8~3",
								value: parseInt(\$monthpickerPrefs.{$monthpicker_id}.year)
							}},
							{tpl:"month",opt:{
					
								value: parseInt(\$monthpickerPrefs.{$monthpicker_id}.month)
							}}
						],
						onChanged: monthpicker_callback
					});
				});
			</script>
EOT;
		return $r;
    }
 
	/**
	 * Display Cell
	 * 
	 * @param  mixed  $cell_name
	 * @param  array  $cell_data
	 * @param  array  $cell_settings  The cell's settings
	 * @return string  Cell HTML
	 */
	function display_cell($cell_name, $cell_data, $cell_settings)
	{
		global $IN;
		
		// if editing or creating a custom field, don't include this js because it's not used, and only throws errors
		if(! ($IN->GBL('M', 'GET') == 'blog_admin' AND $IN->GBL('P', 'GET') == 'edit_field')) {
			$this->include_js('style/scripts/matrix.js');
		}
		return $this->display_field($cell_name, $cell_data, $cell_settings);
	}
	
	/**
	 * Save Field
	 * 
	 * Modify the field's post data before it gets saved to the database
	 * 
	 * @param  mixed  $field_data
	 * @param  array  $$field_settings
	 * @param  array  $entry_id		Only passed if "Postponed saving" is enabled
	 * @return string The modified post data
	 */
	function save_field($field_data, $field_settings, $entry_id = FALSE)
	{
		return strtotime($field_data);
	}

	/**
	 * Save Cell
	 * 
	 * Modify the FF Matrix cell's post data before it gets saved to the database.
	 *
	 * @param  mixed  $cell_data
	 * @param  array  $cell_settings
	 * @param  array  $entry_id		Only passed if "Postponed saving" is enabled
	 * @return string The modified post data
	 */
	function save_cell($cell_data, $cell_settings, $entry_id = FALSE)
	{
		return $this->save_field($cell_data, $cell_settings, $entry_id);
	}
	
	/**
	 * Display Tag (output in template)
	 * 
	 * For now, simple usage: {field_name format='m Y'}
	 * 
	 * @param  array  $params
	 * @param  string  $tagdata
	 * @param  array  $field_data
	 * @param  array  $field_settings
	 * @return string The output sent to the template
	 */
	function display_tag($params, $tagdata, $field_data, $field_settings)
	{
		return date($params['format'], $field_data);
	}
}
?>